#!/usr/bin/env python
#-*- coding: utf-8 -*-
"""
__title__ = 'rfe'
__author__ = 'JieYuan'
__mtime__ = '19-1-30'
"""

"""
https://www.kaggle.com/roydatascience/recursive-feature-selection-new-transactions-elo
"""